Fourcc

Struct Fourcc 

pub struct Fourcc(/* private fields */);

Implementations

Source

impl Fourcc

pub const AUDIO_AC3: Fourcc

Audio Codecs

Dolby AC-3

pub const AUDIO_EC3: Fourcc

Dolby Digital Plus (E-AC-3)

pub const AUDIO_OPUS: Fourcc

Opus Audio Codec

pub const AUDIO_MP3: Fourcc

Mp3 Audio Codec

pub const AUDIO_FLAC: Fourcc

FLAC (Free Lossless Audio Codec)

pub const AUDIO_AAC: Fourcc

ACC (Advanced Audio Coding)

pub const AUDIO_PCM: Fourcc

PCM codec series

pub const AUDIO_PCM_ALAW: Fourcc

pub const AUDIO_PCM_ULAW: Fourcc

pub const VIDEO_VP8: Fourcc

Video Codecs

VP8 Video Codec

pub const VIDEO_VP9: Fourcc

VP9 Video Codec

pub const VIDEO_AV1: Fourcc

AV1 Video Codec

pub const VIDEO_AVC: Fourcc

AVC (H264) Video Codec

pub const VIDEO_HEVC: Fourcc

HEVC (H265) Video Codec

pub const VIDEO_MJPEG: Fourcc

MJPEG Codec

pub const VIDEO_JPEG: Fourcc

JPEG Codec

pub const PIXEL_FORMAT_C1: Fourcc

Pixel formats

| C1 C2 C3 C4 C5 C6 C7 C8 |

pub const PIXEL_FORMAT_C2: Fourcc

| C1 C1 C2 C2 C3 C3 C4 C4 |

pub const PIXEL_FORMAT_C4: Fourcc

| C1 C1 C1 C1 C2 C2 C2 C2 |

pub const PIXEL_FORMAT_C8: Fourcc

| C C C C C C C C |

pub const PIXEL_FORMAT_D1: Fourcc

Darkness (inverse relationship between channel value and brightness)

| D1 D2 D3 D4 D5 D6 D7 D8 |

pub const PIXEL_FORMAT_D2: Fourcc

| D1 D1 D2 D2 D3 D3 D4 D4 |

pub const PIXEL_FORMAT_D4: Fourcc

| C1 C1 C1 C1 C2 C2 C2 C2 |

pub const PIXEL_FORMAT_D8: Fourcc

| D D D D D D D D |

pub const PIXEL_FORMAT_R1: Fourcc

Red (direct relationship between channel value and brightness)

| R1 R2 R3 R4 R5 R6 R7 R8 |

pub const PIXEL_FORMAT_R2: Fourcc

| R1 R1 R2 R2 R3 R3 R4 R4 |

pub const PIXEL_FORMAT_R4: Fourcc

| R1 R1 R1 R1 R2 R2 R2 R2 |

pub const PIXEL_FORMAT_R8: Fourcc

| R R R R R R R R |

pub const PIXEL_FORMAT_R10: Fourcc

10 bpp Red (direct relationship between channel value and brightness)

pub const PIXEL_FORMAT_R12: Fourcc

12 bpp Red (direct relationship between channel value and brightness)

pub const PIXEL_FORMAT_R16: Fourcc

16 bpp Red (direct relationship between channel value and brightness)

pub const PIXEL_FORMAT_RG88: Fourcc

16 bpp RG

pub const PIXEL_FORMAT_GR88: Fourcc

pub const PIXEL_FORMAT_RG1616: Fourcc

32 bpp RG

pub const PIXEL_FORMAT_GR1616: Fourcc

pub const PIXEL_FORMAT_RGB332: Fourcc

8 bpp RGB

| R R R G G G B B |

pub const PIXEL_FORMAT_BGR233: Fourcc

| B B G G G R R R |

pub const PIXEL_FORMAT_XRGB4444: Fourcc

16 bpp RGB

pub const PIXEL_FORMAT_XBGR4444: Fourcc

pub const PIXEL_FORMAT_RGBX4444: Fourcc

pub const PIXEL_FORMAT_BGRX4444: Fourcc

pub const PIXEL_FORMAT_ARGB4444: Fourcc

pub const PIXEL_FORMAT_ABGR4444: Fourcc

pub const PIXEL_FORMAT_RGBA4444: Fourcc

pub const PIXEL_FORMAT_BGRA4444: Fourcc

pub const PIXEL_FORMAT_XRGB1555: Fourcc

pub const PIXEL_FORMAT_XBGR1555: Fourcc

pub const PIXEL_FORMAT_RGBX5551: Fourcc

pub const PIXEL_FORMAT_BGRX5551: Fourcc

pub const PIXEL_FORMAT_ARGB1555: Fourcc

pub const PIXEL_FORMAT_ABGR1555: Fourcc

pub const PIXEL_FORMAT_RGBA5551: Fourcc

pub const PIXEL_FORMAT_BGRA5551: Fourcc

pub const PIXEL_FORMAT_RGB565: Fourcc

pub const PIXEL_FORMAT_BGR565: Fourcc

pub const PIXEL_FORMAT_RGB888: Fourcc

pub const PIXEL_FORMAT_BGR888: Fourcc

pub const PIXEL_FORMAT_XRGB8888: Fourcc

pub const PIXEL_FORMAT_XBGR8888: Fourcc

pub const PIXEL_FORMAT_RGBX8888: Fourcc

pub const PIXEL_FORMAT_BGRX8888: Fourcc

pub const PIXEL_FORMAT_ARGB8888: Fourcc

pub const PIXEL_FORMAT_ABGR8888: Fourcc

pub const PIXEL_FORMAT_RGBA8888: Fourcc

pub const PIXEL_FORMAT_BGRA8888: Fourcc

pub const PIXEL_FORMAT_XRGB2101010: Fourcc

pub const PIXEL_FORMAT_XBGR2101010: Fourcc

pub const PIXEL_FORMAT_RGBX1010102: Fourcc

pub const PIXEL_FORMAT_BGRX1010102: Fourcc

pub const PIXEL_FORMAT_ARGB2101010: Fourcc

pub const PIXEL_FORMAT_ABGR2101010: Fourcc

pub const PIXEL_FORMAT_RGBA1010102: Fourcc

pub const PIXEL_FORMAT_BGRA1010102: Fourcc

pub const PIXEL_FORMAT_XRGB16161616: Fourcc

pub const PIXEL_FORMAT_XBGR16161616: Fourcc

pub const PIXEL_FORMAT_ARGB16161616: Fourcc

pub const PIXEL_FORMAT_ABGR16161616: Fourcc

pub const PIXEL_FORMAT_XRGB16161616F: Fourcc

Floating point 64bpp RGB IEEE 754-2008 binary16 half-precision float [15:0] sign:exponent:mantissa 1:5:10

pub const PIXEL_FORMAT_XBGR16161616F: Fourcc

pub const PIXEL_FORMAT_ARGB16161616F: Fourcc

pub const PIXEL_FORMAT_ABGR16161616F: Fourcc

pub const PIXEL_FORMAT_AXBXGXRX106106106106: Fourcc

RGBA format with 10-bit components packed in 64-bit per pixel, with 6 bits of unused padding per component:

pub const PIXEL_FORMAT_YUYV: Fourcc

pub const PIXEL_FORMAT_YVYU: Fourcc

pub const PIXEL_FORMAT_UYVY: Fourcc

pub const PIXEL_FORMAT_VYUY: Fourcc

pub const PIXEL_FORMAT_AYUV: Fourcc

pub const PIXEL_FORMAT_AVUY8888: Fourcc

pub const PIXEL_FORMAT_XYUV8888: Fourcc

pub const PIXEL_FORMAT_XVUY8888: Fourcc

pub const PIXEL_FORMAT_VUY888: Fourcc

pub const PIXEL_FORMAT_VUY101010: Fourcc

pub const PIXEL_FORMAT_Y210: Fourcc

pub const PIXEL_FORMAT_Y212: Fourcc

pub const PIXEL_FORMAT_Y216: Fourcc

pub const PIXEL_FORMAT_Y410: Fourcc

pub const PIXEL_FORMAT_Y412: Fourcc

pub const PIXEL_FORMAT_Y416: Fourcc

pub const PIXEL_FORMAT_XVYU2101010: Fourcc

pub const PIXEL_FORMAT_XVYU12_16161616: Fourcc

pub const PIXEL_FORMAT_XVYU16161616: Fourcc

pub const PIXEL_FORMAT_YUV420_8BIT: Fourcc

1-plane YUV 4:2:0 In these formats, the component ordering is specified (Y, followed by U then V), but the exact Linear layout is undefined. These formats can only be used with a non-Linear modifier.

pub const PIXEL_FORMAT_YUV420_10BIT: Fourcc

pub const PIXEL_FORMAT_XRGB8888_A8: Fourcc

2 plane RGB + A index 0 = RGB plane, same format as the corresponding non _A8 format has index 1 = A plane, [7:0] A

pub const PIXEL_FORMAT_XBGR8888_A8: Fourcc

pub const PIXEL_FORMAT_RGBX8888_A8: Fourcc

pub const PIXEL_FORMAT_BGRX8888_A8: Fourcc

pub const PIXEL_FORMAT_RGB888_A8: Fourcc

pub const PIXEL_FORMAT_BGR888_A8: Fourcc

pub const PIXEL_FORMAT_RGB565_A8: Fourcc

pub const PIXEL_FORMAT_BGR565_A8: Fourcc

pub const PIXEL_FORMAT_NV12: Fourcc

2 plane YCbCr index 0 = Y plane, [7:0] Y index 1 = Cr:Cb plane, [15:0] Cr:Cb little endian or index 1 = Cb:Cr plane, [15:0] Cb:Cr little endian

pub const PIXEL_FORMAT_NV21: Fourcc

pub const PIXEL_FORMAT_NV16: Fourcc

pub const PIXEL_FORMAT_NV61: Fourcc

pub const PIXEL_FORMAT_NV24: Fourcc

pub const PIXEL_FORMAT_NV42: Fourcc

pub const PIXEL_FORMAT_NV15: Fourcc

2 plane YCbCr index 0 = Y plane, [39:0] Y3:Y2:Y1:Y0 little endian index 1 = Cr:Cb plane, [39:0] Cr1:Cb1:Cr0:Cb0 little endian

pub const PIXEL_FORMAT_NV20: Fourcc

pub const PIXEL_FORMAT_NV30: Fourcc

pub const PIXEL_FORMAT_P210: Fourcc

2 plane YCbCr MSB aligned index 0 = Y plane, [15:0] Y:x [10:6] little endian index 1 = Cr:Cb plane, [31:0] Cr:x:Cb:x [10:6:10:6] little endian

pub const PIXEL_FORMAT_P010: Fourcc

2 plane YCbCr MSB aligned index 0 = Y plane, [15:0] Y:x [10:6] little endian index 1 = Cr:Cb plane, [31:0] Cr:x:Cb:x [10:6:10:6] little endian

pub const PIXEL_FORMAT_P012: Fourcc

2 plane YCbCr MSB aligned index 0 = Y plane, [15:0] Y:x [12:4] little endian index 1 = Cr:Cb plane, [31:0] Cr:x:Cb:x [12:4:12:4] little endian

pub const PIXEL_FORMAT_P016: Fourcc

2 plane YCbCr MSB aligned index 0 = Y plane, [15:0] Y little endian index 1 = Cr:Cb plane, [31:0] Cr:Cb [16:16] little endian

pub const PIXEL_FORMAT_P030: Fourcc

2 plane YCbCr42 3 10 bit components and 2 padding bits packed into 4 bytes. index 0 = Y plane, [31:0] x:Y2:Y1:Y0 2:10:10:10 little endian index 1 = Cr:Cb plane, [63:0] x:Cr2:Cb2:Cr1:x:Cb1:Cr0:Cb0 [2:10:10:10:2:10:10:10] little endian

pub const PIXEL_FORMAT_Q410: Fourcc

3 plane non-subsampled (444) YCb 16 bits per component, but only 10 bits are used and 6 bits are padded index 0: Y plane, [15:0] Y:x [10:6] little endian index 1: Cb plane, [15:0] Cb:x [10:6] little endian index 2: Cr plane, [15:0] Cr:x [10:6] little endian

pub const PIXEL_FORMAT_Q401: Fourcc

3 plane non-subsampled (444) YCr 16 bits per component, but only 10 bits are used and 6 bits are padded index 0: Y plane, [15:0] Y:x [10:6] little endian index 1: Cr plane, [15:0] Cr:x [10:6] little endian index 2: Cb plane, [15:0] Cb:x [10:6] little endian

pub const PIXEL_FORMAT_YUV410: Fourcc

3 plane YCbCr index 0: Y plane, [7:0] Y index 1: Cb plane, [7:0] Cb index 2: Cr plane, [7:0] Cr or index 1: Cr plane, [7:0] Cr index 2: Cb plane, [7:0] Cb

pub const PIXEL_FORMAT_YVU410: Fourcc

pub const PIXEL_FORMAT_YUV411: Fourcc

pub const PIXEL_FORMAT_YVU411: Fourcc

pub const PIXEL_FORMAT_YUV420: Fourcc

pub const PIXEL_FORMAT_YVU420: Fourcc

pub const PIXEL_FORMAT_YUV422: Fourcc

pub const PIXEL_FORMAT_YVU422: Fourcc

pub const PIXEL_FORMAT_YUV444: Fourcc

pub const PIXEL_FORMAT_YVU444: Fourcc

pub const fn from_static(s: &str) -> Self